Skip to contents

Returns a ggplot contour plot of the third-order moment region that exceeds the bootstrap test limits computed by nonlintest(). Returns NULL invisibly with an informational message if no points exceed the limits.

Usage

# S3 method for class 'nonlintest'
autoplot(object, ...)

Arguments

object

a nonlintest object produced by nonlintest().

...

unused, for S3 generic compatibility.

Value

a ggplot contour plot, or NULL invisibly when no points exceed the test limits.

See also

Author

Nicholas Tierney

Examples

# \donttest{
if (FALSE) { # \dontrun{
test_res <- nonlintest(data = CVD$cvd, n.lag = 4, n.boot = 1000)
autoplot(test_res)
} # }
# }