Skip to contents

Returns a ggplot of the trend and seasonal components estimated by nscosinor(), faceted by component and with a ribbon for the confidence interval.

Usage

# S3 method for class 'nsCosinor'
autoplot(object, ...)

Arguments

object

an nsCosinor object produced by nscosinor().

...

unused, for S3 generic compatibility.

Value

a ggplot object faceted by trend / season(s).

See also

Author

Nicholas Tierney

Examples

# \donttest{
if (FALSE) { # \dontrun{
res <- nscosinor(
  data = CVD, response = "adj", cycles = 12,
  niters = 200, burnin = 100, tau = c(10, 50)
)
autoplot(res)
autoplot(res) + ggplot2::theme_minimal()
} # }
# }