Internal function to do a forward and backward sweep of the Kalman filter, used by nscosinor. For internal use only.
kalfil(data, f, vartheta, w, tau, lambda, cmean)a data frame.
vector of cycles in units of time.
variance for noise.
variance of seasonal component.
controls flexibility of trend and season.
distance between observations.
used to give a vague prior for the starting values.