Skip to contents

[Deprecated] Soft-deprecated in favour of autoplot.nonlintest(), which returns a ggplot object you can extend with +. The base R-style plot below still works.

Usage

# S3 method for class 'nonlintest'
plot(x, plot = lifecycle::deprecated(), ...)

Arguments

x

a nonlintest object produced by nonlintest().

plot

[Deprecated] display plot (TRUE) or return plot (FALSE).

...

additional arguments to plot()

Value

ggplot Contour plot of the region of the third-order moment outside the test limits generated by nonlintest().

Author

Adrian Barnett a.barnett@qut.edu.au

Examples

# \donttest{
test_res <- nonlintest(data = CVD$cvd, n.lag = 4, n.boot = 1000)
# Recommended:
autoplot(test_res)

# Still works, but deprecated:
plot(test_res)
#> Warning: `plot.nonlintest()` was deprecated in season 0.3.17.
#> Use `autoplot()` for a ggplot object you can extend:
#>   autoplot(x) + ggplot2::theme_bw()

# }