Skip to contents

[Deprecated] Soft-deprecated in favour of autoplot.nsCosinor(), which is the same ggplot — just nudges the recommended idiom so users can + theme_bw() etc.

Usage

# S3 method for class 'nsCosinor'
plot(x, ...)

Arguments

x

a nsCosinor object produced by nscosinor().

...

further arguments passed to or from other methods.

Value

a plot of class ggplot.

Details

The code produces the season(s) and trend estimates.

Author

Adrian Barnett a.barnett@qut.edu.au

Examples

# \donttest{
# model to fit an annual pattern to the monthly cardiovascular disease data
f <- 12
tau <- c(10,50)
if (FALSE) { # \dontrun{
  res12 <- nscosinor(
    data = CVD,
    response = 'adj',
    cycles = f,
    niters = 200,
    burnin = 100,
    tau = tau
    )
# Recommended:
autoplot(res12)
# Still works, but deprecated:
plot(res12)
} # }
# }