Circular plot of a monthly variable. This circular plot can be useful for estimates of an annual seasonal pattern. Darker shades of grey correspond to larger numbers. Pie chart where each segment is one month and the fill is shaded to indicate the value (darker = larger). The first value is assumed to be January. This circular plot can be useful for estimates of an annual seasonal pattern. Darker shades of grey correspond to larger numbers.
See also
plotCircle() (deprecated base R version)