monthglm(formula, data, family=gaussian(), refmonth=1,
monthvar='month',offsetmonth=FALSE, offsetpop=NULL)
## S3 method for class 'monthglm':
print(x, ...)y~x1+x2, (do not
add month to the regression equation, it will be added
automatically).gaussian()). (See
family for details of family functions.).family=poisson()).monthglmformula.
This model is useful for examining non-sinusoidal seasonal
patterns. For sinusoidal seasonal patterns see cosinor.
The data frame should contain the integer months and the year as a 4 digit number. These are used to calculate the number of days in each month accounting for leap years.summary.monthglm, plot.monthglmdata(CVD)
mmodel = monthglm(formula=cvd~1 ,data=CVD, family=poisson(),
offsetpop=pop/100000, offsetmonth=TRUE)
summary(mmodel)Run the code above in your browser using DataLab