For time series recorded at monthly intervals it is often useful to examine
(and plot) the average in each month. When using count data we should adjust
the mean to account for the unequal number of days in the month (e.g., 31 in
January and 28 or 29 in February).
This function assumes that the data set (data) contains variables for
the year and month called year and month, respectively.
References
Barnett, A.G., Dobson, A.J. (2010) Analysing Seasonal
Health Data. Springer.