powered by
Calculate the phase given the estimated sine and cosine values from a cosinor model.
phasecalc(cosine, sine)
Estimated phase in radians.
estimated cosine value from a cosinor model.
estimated sine value from a cosinor model.
Adrian Barnett a.barnett@qut.edu.au
Returns the phase in radians, in the range \([0,2\pi)\). The phase is the peak in the sinusoid.
Fisher, N.I. (1993) Statistical Analysis of Circular Data. Cambridge University Press, Cambridge. Page 31.
phasecalc(cosine=0, sine=1) # pi/2
Run the code above in your browser using DataLab